.. _acc:

##############
Accuracy Table
##############

.. currentmodule:: fitbenchmarking.results_processing.acc_table
.. autoclass:: fitbenchmarking.results_processing.acc_table.AccTable
	       :noindex:
